@@ -4,7 +4,7 @@
 
     Lexer for Tera Term macro files.
 
-    :copyright: Copyright 2006-2021 by the Pygments team, see AUTHORS.
+    :copyright: Copyright 2006-2023 by the Pygments team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -12,19 +12,20 @@ import re
 
 from pygments.lexer import RegexLexer, include, bygroups
 from pygments.token import Text, Comment, Operator, Name, String, \
-    Number, Keyword
+    Number, Keyword, Error
 
 __all__ = ['TeraTermLexer']
 
 
 class TeraTermLexer(RegexLexer):
     """
-    For `Tera Term <https://ttssh2.osdn.jp/>`_ macro source code.
+    For Tera Term macro source code.
 
     .. versionadded:: 2.4
     """
     name = 'Tera Term macro'
-    aliases = ['ttl', 'teraterm', 'teratermmacro']
+    url = 'https://ttssh2.osdn.jp/'
+    aliases = ['teratermmacro', 'teraterm', 'ttl']
     filenames = ['*.ttl']
     mimetypes = ['text/x-teratermmacro']
 
@@ -51,7 +52,7 @@ class TeraTermLexer(RegexLexer):
             (r'[*/]', Comment.Multiline)
         ],
         'labels': [
-            (r'(?i)^(\s*)(:[a-z0-9_]+)', bygroups(Text, Name.Label)),
+            (r'(?i)^(\s*)(:[a-z0-9_]+)', bygroups(Text.Whitespace, Name.Label)),
         ],
         'commands': [
             (
@@ -259,7 +260,7 @@ class TeraTermLexer(RegexLexer):
                 Keyword,
             ),
             (r'(?i)(call|goto)([ \t]+)([a-z0-9_]+)',
-             bygroups(Keyword, Text, Name.Label)),
+             bygroups(Keyword, Text.Whitespace, Name.Label)),
         ],
         'builtin-variables': [
             (
@@ -302,20 +303,11 @@ class TeraTermLexer(RegexLexer):
         ],
         'string-literals': [
             (r'(?i)#(?:[0-9]+|\$[0-9a-f]+)', String.Char),
-            (r"'", String.Single, 'in-single-string'),
-            (r'"', String.Double, 'in-double-string'),
-        ],
-        'in-general-string': [
-            (r'\\[\\nt]', String.Escape),  # Only three escapes are supported.
-            (r'.', String),
-        ],
-        'in-single-string': [
-            (r"'", String.Single, '#pop'),
-            include('in-general-string'),
-        ],
-        'in-double-string': [
-            (r'"', String.Double, '#pop'),
-            include('in-general-string'),
+            (r"'[^'\n]*'", String.Single),
+            (r'"[^"\n]*"', String.Double),
+            # Opening quotes without a closing quote on the same line are errors.
+            (r"('[^']*)(\n)", bygroups(Error, Text.Whitespace)),
+            (r'("[^"]*)(\n)', bygroups(Error, Text.Whitespace)),
         ],
         'operators': [
             (r'and|not|or|xor', Operator.Word),
@@ -323,7 +315,7 @@ class TeraTermLexer(RegexLexer):
             (r'[()]', String.Symbol),
         ],
         'all-whitespace': [
-            (r'\s+', Text),
+            (r'\s+', Text.Whitespace),
         ],
     }
 
